#!/bin/sh

REMOTEIT_DIR=/usr/share/remoteit
INSTALL_API=https://install.remote.it/v1
CONFIG_FILE=/etc/remoteit/config.json
REGISTRATION=/etc/remoteit/registration

VERSION=$(cat $REMOTEIT_DIR/version.txt)

. $REMOTEIT_DIR/systemd.sh
. $REMOTEIT_DIR/oem.sh

r3_update_config() {
  r3_logger "Updating remote.it configuration."

  local config

  if [ -f $CONFIG_FILE ]; then
    config=$(cat $CONFIG_FILE)
  elif [ -f $REGISTRATION ]; then
    local registration=$(cat $REGISTRATION)

    [ -n "$registration" ] || return 0

    config=$(jq -n --arg registration "$registration" '{$registration}')
  else
    config='{}'
  fi

  jq -n \
    --argjson config "$config" \
    --arg name "$(r3_get_name)" \
    --arg identity "$(r3_get_identity)" \
    --argjson manufacturer "$(r3_get_manufacturer)" \
    --argjson platform "$(r3_get_platform)" \
    --argjson metadata "$(r3_get_metadata)" \
    '$config * {$name, $identity, $manufacturer, $platform, $metadata}' | sudo /bin/sh -c "curl -sfo $CONFIG_FILE -d @- $INSTALL_API/refresh"
}

r3_update_instances() {
  r3_update_config
   
  r3_add_schannel

  if [ -r $CONFIG_FILE ]; then
    for id in $(jq -r '.device,.services[] | .id' "$CONFIG_FILE"); do
      r3_enable_instance remoteit@"$id"
    done
  fi

  r3_restart_services
}

r3_get_claim() {
  local claim

  [ -r $CONFIG_FILE ] && claim=$(jq -er '.device.claim' "$CONFIG_FILE") && echo "$claim"
}

r3_install_agent() {
  r3_logger "Installing remote.it agent."

  sudo mkdir -p /etc/remoteit

  [ -r $CONFIG_FILE ] || r3_update_config

  sudo ln -sf $REMOTEIT_DIR/task_notify.sh /usr/bin/connectd_task_notify

  r3_start_service connectd

  local code=$(r3_get_claim)

  if [ -n "$code" ]; then
    echo
    echo "--------------------- Claim this device ---------------------"
    echo
    echo "Use the code $code to register this device to your account"
    echo
    echo "--------------------- Claim this device ---------------------"
    echo
  fi
}

r3_remove_agent() {
  r3_logger "Removing remote.it agent."

  cd /etc/systemd/system/multi-user.target.wants
  for service in remoteit*.service ; do
    r3_stop_service $service
  done
  cd -
  r3_stop_service connectd
  r3_stop_service schannel

  sudo rm -f /usr/bin/connectd_task_notify
  sudo rm -r /usr/share/remoteit
}

r3_reload_agent() {
  r3_start_instance connectd
}

r3_task_notify() {
  echo "200 OK"
}
